diff --git a/python_binding/operator/pybind_Operator.cpp b/python_binding/operator/pybind_Operator.cpp
index 6b535e8cf3293b26aaa64f95ca2f9a394768935f..6154c5b569d04d61514c5663590d04bfafcd931e 100644
--- a/python_binding/operator/pybind_Operator.cpp
+++ b/python_binding/operator/pybind_Operator.cpp
@@ -21,6 +21,8 @@ void init_Operator(py::module& m){
     .def("output", &Operator::output, py::arg("outputIdx"))
     .def("input", &Operator::input, py::arg("inputIdx"))
     .def("nb_data_inputs", &Operator::nbDataInputs)
+    .def("nb_outputs", &Operator::nbOutputs)
+    .def("output_dims_forwarded", &Operator::outputDimsForwarded)
     .def("associate_input", &Operator::associateInput, py::arg("inputIdx"), py::arg("data"))
     .def("set_datatype", &Operator::setDatatype, py::arg("datatype"))
     .def("set_backend", &Operator::setBackend, py::arg("name"))
diff --git a/python_binding/graph/pybind_GraphView.cpp b/python_binding/graph/pybind_GraphView.cpp
index 6ac2199b4ba59faba16c9815277ad134c6f183f4..02b69b857e11633437671575ea870152059a78d8 100644
--- a/python_binding/graph/pybind_GraphView.cpp
+++ b/python_binding/graph/pybind_GraphView.cpp
@@ -51,9 +51,18 @@ void init_GraphView(py::module& m) {
           Include a Node to the current GraphView object.
 
           :param other_node: Node to add
-          :type oth_Node: Node
-          :param includeLearnableParameter: include non-data inputs, like weights and biases. Default True.
-          :type includeLearnableParameter: bool
+          :type other_node: Node
+          :param include_learnable_parameters: include non-data inputs, like weights and biases, default True.
+          :type include_learnable_parameters: bool, optional
+          )mydelimiter")
+
+          .def("add", (void (GraphView::*)(std::shared_ptr<GraphView>)) & GraphView::add,
+               py::arg("other_graph"),
+          R"mydelimiter(
+          Include a GraphView to the current GraphView object.
+
+          :param other_graph: GraphView to add
+          :type otherGraph: GraphView
           )mydelimiter")
 
           .def("add_child",
@@ -105,4 +114,4 @@ void init_GraphView(py::module& m) {
           //      })
             ;
 }
-}  // namespace Aidge
\ No newline at end of file
+}  // namespace Aidge